/* 
 * Datei: pcf8583.h
 * Info: Routinen zum Einlesen und Setzen der i2C-Uhr PCF8583
 * Autor: Werner Bllmann
 * Datum: 10.04.2005
 * 21.4.2005 wb - sommerzeitstatus in RAM 0x12
 *
 * RAM Belegung: 0x10+0x11 = Vollstaendiges Jahr
 *               0x12      = Sommerzeitstatus von DCF77
 *
 */

typedef union {
    uint8_t bytes[18];
    struct {
        uint8_t control;    // 0
        uint8_t h_sec;      // 1
        uint8_t sec;        // 2
        uint8_t min;        // 3
        uint8_t hr;         // 4
        uint16_t days:6;    // 5
        uint16_t yr:2;
        uint16_t month:5;
        uint16_t weekday:3;
        //uint8_t wd_mon;     // 6
        uint8_t timer_day;  // 7 
        uint8_t alarmcontrol; // 8
        uint8_t a_hsec;     // 9
        uint8_t a_sec;      // A
        uint8_t a_min;      // B
        uint8_t a_hr;       // C
        uint8_t a_date;     // D
        uint8_t a_mon;      // E
        uint8_t a_timer;    // F
        uint16_t year;      // 10/11
        uint8_t  dst;       // 12  - daylight savings time status von DCF77
    };
} pcf8583_ctl; 

extern void twi_init(void);
// ret = len read/written or -1 on error - twst is set
extern int8_t read_pcf8583(pcf8583_ctl *data);
extern int8_t write_pcf8583(pcf8583_ctl *data);

// ===========================================================================================
// Internally used

#define STOP        0x80
#define CAPTURE     0x40
#define READ_MASKED 0x08

extern uint8_t twst;

extern int8_t twi_read_bytes(uint8_t sla, uint8_t addr, uint8_t len, uint8_t *buf);
extern int8_t twi_write_bytes(uint8_t als, uint8_t addr, uint8_t len, uint8_t *buf);

#define MAX_ITER  15

#define FULL_YEAR_ADDR 0x10
#define FULL_YEAR_LEN  2



